@@ -27,6 +27,7 @@
 #elif defined(__linux__)
 #include <linux/if.h>
 #endif
+#include <net/if_arp.h>
 #include <errno.h>
 #include <assert.h>
 #include <ctype.h>
@@ -179,6 +180,30 @@ int check_kill_switch(const char *iface)
 
 #undef SYSCLASSNET
 
+int is_raw_80211(const char *iface)
+{
+    struct ifreq ifr;
+    struct sockaddr sa;
+    
+    strncpy(ifr.ifr_name, iface, IFNAMSIZ);
+    
+    if (skfd && ioctl(skfd, SIOCGIFHWADDR, &ifr) < 0) {
+        di_warning("Unable to retrieve interface type.");
+        return 0;
+    }
+
+    sa = * (struct sockaddr *) &ifr.ifr_hwaddr;
+    switch (sa.sa_family) {
+    case ARPHRD_IEEE80211:
+    case ARPHRD_IEEE80211_PRISM:
+    case ARPHRD_IEEE80211_RADIOTAP:
+        return 1;
+
+    default:
+        return 0;
+    }
+}
+
 int is_interface_up(char *inter)
 {
     struct ifreq ifr;
@@ -238,6 +263,8 @@ int get_all_ifs (int all, char*** ptr)
             continue;
         if (!strncmp(ibuf, "sit", 3))        /* ignore tunnel devices */
             continue;
+        if (is_raw_80211(ibuf))
+            continue;
         if (all || is_interface_up(ibuf) == 1) {
             list = realloc(list, sizeof(char*) * (len + 1));
             list[len] = strdup(ibuf);
@@ -475,11 +502,11 @@ int netcfg_get_interface(struct debconfclient *client, char **interface,
     
     if (num_interfaces == 0) {
         debconf_input(client, "high", "netcfg/no_interfaces");
-        debconf_go(client);
+        ret = debconf_go(client);
         free(ptr);
         free(old_selection);
         *numif = 0;
-        return 0;
+        return ret;
     }
     else if (num_interfaces == 1) {
         inter = ptr;
@@ -554,7 +581,7 @@ short verify_hostname (char *hname)
     len = strlen(hname);
     
     /* Check the hostname for RFC 1123 compliance.  */
-    if ((len < 2) ||
+    if ((len < 1) ||
         (len > 63) ||
         (strspn(hname, valid_chars) != len) ||
         (hname[len - 1] == '-') ||
